<?php
/**
 * Contact Section options
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 */

// Add Contact section
$wp_customize->add_section( 'pleased_pro_contact_section', array(
	'title'             => esc_html__( 'Contact','pleased-pro' ),
	'description'       => esc_html__( 'Contact Section options.', 'pleased-pro' ),
	'panel'             => 'pleased_pro_front_page_panel',
) );

// Contact content enable control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[contact_section_enable]', array(
	'default'			=> 	$options['contact_section_enable'],
	'sanitize_callback' => 'pleased_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pleased_Pro_Switch_Control( $wp_customize, 'pleased_pro_theme_options[contact_section_enable]', array(
	'label'             => esc_html__( 'Contact Section Enable', 'pleased-pro' ),
	'section'           => 'pleased_pro_contact_section',
	'on_off_label' 		=> pleased_pro_switch_options(),
) ) );

// contact title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[contact_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['contact_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[contact_title]', array(
	'label'           	=> esc_html__( 'Title', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_contact_section',
	'active_callback' 	=> 'pleased_pro_is_contact_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[contact_title]', array(
		'selector'            => '#contact-us .entry-header h2.entry-title',
		'settings'            => 'pleased_pro_theme_options[contact_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_contact_title_partial',
    ) );
}

// contact sub title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[contact_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['contact_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[contact_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_contact_section',
	'active_callback' 	=> 'pleased_pro_is_contact_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[contact_sub_title]', array(
		'selector'            => '#contact-us .entry-header p',
		'settings'            => 'pleased_pro_theme_options[contact_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_contact_sub_title_partial',
    ) );
}

// Contact address setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[contact_address]', array(
	'sanitize_callback' => 'sanitize_textarea_field',
	'default'			=> $options['contact_address'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[contact_address]', array(
	'label'           	=> esc_html__( 'Address', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_contact_section',
	'active_callback' 	=> 'pleased_pro_is_contact_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[contact_address]', array(
		'selector'            => '#contact-us .address-block .address span',
		'settings'            => 'pleased_pro_theme_options[contact_address]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_contact_address_partial',
    ) );
}

// contact email setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[contact_email]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['contact_email'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( new Pleased_Pro_Multi_Input_Custom_Control( $wp_customize, 'pleased_pro_theme_options[contact_email]', array(
	'label'             => esc_html__( 'Email ID', 'pleased-pro' ),
	'button_text'       => esc_html__( 'Add Email ID.', 'pleased-pro' ),
	'section'           => 'pleased_pro_contact_section',
	'active_callback' 	=> 'pleased_pro_is_contact_section_enable',
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[contact_email]', array(
		'selector'            => '#contact-us .address-block .website span',
		'settings'            => 'pleased_pro_theme_options[contact_email]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_contact_email_partial',
    ) );
}

// Contact phone control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[contact_phone]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['contact_phone'],
) );

$wp_customize->add_control( new Pleased_Pro_Multi_Input_Custom_Control( $wp_customize, 'pleased_pro_theme_options[contact_phone]', array(
	'label'             => esc_html__( 'Phone No', 'pleased-pro' ),
	'button_text'       => esc_html__( 'Add Phone No.', 'pleased-pro' ),
	'section'           => 'pleased_pro_contact_section',
	'active_callback' 	=> 'pleased_pro_is_contact_section_enable',
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[contact_phone]', array(
		'selector'            => '#contact-us .address-block .phone span',
		'settings'            => 'pleased_pro_theme_options[contact_phone]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_contact_phone_partial',
    ) );
}

// Contact website setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[contact_map]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[contact_map]', array(
	'label'           	=> esc_html__( 'Map', 'pleased-pro' ),
	'description'       => sprintf( '%1$s <a href="' . esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins&plugin_status=install' ) ) . '" target="_blank"> %2$s </a> %3$s', esc_html__( 'To enable google map. Use shortcode from WP Google Maps plugin. ', 'pleased-pro' ), esc_html__( 'Click Here', 'pleased-pro' ), esc_html__( 'to download.', 'pleased-pro' ) ),
	'section'        	=> 'pleased_pro_contact_section',
	'active_callback' 	=> 'pleased_pro_is_contact_section_enable',
	'type'				=> 'text',
) );

// Contact social control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[contact_social]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_links',
	'default'			=> $options['contact_social'],
) );

$wp_customize->add_control( new Pleased_Pro_Multi_Input_Custom_Control( $wp_customize, 'pleased_pro_theme_options[contact_social]', array(
	'label'             => esc_html__( 'Social Link', 'pleased-pro' ),
	'button_text'       => esc_html__( 'Add Social Link.', 'pleased-pro' ),
	'section'           => 'pleased_pro_contact_section',
	'active_callback' 	=> 'pleased_pro_is_contact_section_enable',
) ) );