<?php
/**
 * Package Section options
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 */

// Add Package section
$wp_customize->add_section( 'pleased_pro_package_section', array(
	'title'             => esc_html__( 'Package','pleased-pro' ),
	'description'       => esc_html__( 'Package Section options.', 'pleased-pro' ),
	'panel'             => 'pleased_pro_front_page_panel',
) );

// Package content enable control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[package_section_enable]', array(
	'default'			=> 	$options['package_section_enable'],
	'sanitize_callback' => 'pleased_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pleased_Pro_Switch_Control( $wp_customize, 'pleased_pro_theme_options[package_section_enable]', array(
	'label'             => esc_html__( 'Package Section Enable', 'pleased-pro' ),
	'section'           => 'pleased_pro_package_section',
	'on_off_label' 		=> pleased_pro_switch_options(),
) ) );

// package title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[package_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[package_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_package_section',
	'active_callback' 	=> 'pleased_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[package_sub_title]', array(
		'selector'            => '#luxury-room .section-header span.section-subtitle',
		'settings'            => 'pleased_pro_theme_options[package_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_package_sub_title_partial',
    ) );
}

// package title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[package_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[package_title]', array(
	'label'           	=> esc_html__( 'Title', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_package_section',
	'active_callback' 	=> 'pleased_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[package_title]', array(
		'selector'            => '#luxury-room .section-header h2.section-title',
		'settings'            => 'pleased_pro_theme_options[package_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_package_title_partial',
    ) );
}

// Package content type control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[package_content_type]', array(
	'default'          	=> $options['package_content_type'],
	'sanitize_callback' => 'pleased_pro_sanitize_select',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[package_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pleased-pro' ),
	'section'           => 'pleased_pro_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pleased_pro_is_package_section_enable',
	'choices'			=> pleased_pro_package_content_type(),
) );

for ( $i=1; $i <= 4 ; $i++ ) { 
	// package pages drop down chooser control and setting
	$wp_customize->add_setting( 'pleased_pro_theme_options[package_content_page_' . $i . ']', array(
		'sanitize_callback' => 'pleased_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pleased_Pro_Dropdown_Chooser( $wp_customize, 'pleased_pro_theme_options[package_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'pleased-pro' ), $i ),
		'section'           => 'pleased_pro_package_section',
		'choices'			=> pleased_pro_page_choices(),
		'active_callback'	=> 'pleased_pro_is_package_section_content_page_enable',
	) ) );

	// package posts drop down chooser control and setting
	$wp_customize->add_setting( 'pleased_pro_theme_options[package_content_post_' . $i . ']', array(
		'sanitize_callback' => 'pleased_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pleased_Pro_Dropdown_Chooser( $wp_customize, 'pleased_pro_theme_options[package_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'pleased-pro' ), $i ),
		'section'           => 'pleased_pro_package_section',
		'choices'			=> pleased_pro_post_choices(),
		'active_callback'	=> 'pleased_pro_is_package_section_content_post_enable',
	) ) );

	// package trips drop down chooser control and setting
	$wp_customize->add_setting( 'pleased_pro_theme_options[package_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'pleased_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pleased_Pro_Dropdown_Chooser( $wp_customize, 'pleased_pro_theme_options[package_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'pleased-pro' ), $i ),
		'section'           => 'pleased_pro_package_section',
		'choices'			=> pleased_pro_trip_choices(),
		'active_callback'	=> 'pleased_pro_is_package_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[package_content_category]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pleased_pro_theme_options[package_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'pleased-pro' ),
	'section'           => 'pleased_pro_package_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_package_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[package_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pleased_pro_theme_options[package_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'pleased-pro' ),
	'section'           => 'pleased_pro_package_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_package_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[package_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pleased_pro_theme_options[package_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'pleased-pro' ),
	'section'           => 'pleased_pro_package_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_package_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[package_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pleased_pro_theme_options[package_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'pleased-pro' ),
	'section'           => 'pleased_pro_package_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_package_section_content_destination_enable'
) ) );

// package btn title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[package_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[package_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_package_section',
	'active_callback' 	=> 'pleased_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[package_btn_title]', array(
		'selector'            => '#luxury-room .section-content .btn-primary',
		'settings'            => 'pleased_pro_theme_options[package_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_package_btn_title_partial',
    ) );
}

// package btn link setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[package_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[package_btn_url]', array(
	'label'           	=> esc_html__( 'Button link', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_package_section',
	'active_callback' 	=> 'pleased_pro_is_package_section_enable',
	'type'				=> 'url',
) );
